Class: MachO::LoadCommands::DysymtabCommand
- Inherits:
-
LoadCommand
- Object
- MachOStructure
- LoadCommand
- MachO::LoadCommands::DysymtabCommand
- Defined in:
- lib/macho/load_commands.rb
Overview
A load command containing symbolic information needed to support data structures used by the dynamic link editor. Corresponds to LC_DYSYMTAB.
Instance Method Summary collapse
-
#extrefsymoff ⇒ Integer
The file offset to the referenced symbol table.
-
#extreloff ⇒ Integer
The file offset to the external relocation entries.
-
#iextdefsym ⇒ Integer
The index to externally defined symbols.
-
#ilocalsym ⇒ Integer
The index to local symbols.
-
#indirectsymoff ⇒ Integer
The file offset to the indirect symbol table.
-
#iundefsym ⇒ Integer
The index to undefined symbols.
-
#locreloff ⇒ Integer
The file offset to the local relocation entries.
-
#modtaboff ⇒ Integer
The file offset to the module table.
-
#nextdefsym ⇒ Integer
The number of externally defined symbols.
-
#nextrefsyms ⇒ Integer
The number of entries in the referenced symbol table.
-
#nextrel ⇒ Integer
The number of external relocation entries.
-
#nindirectsyms ⇒ Integer
The number of entries in the indirect symbol table.
-
#nlocalsym ⇒ Integer
The number of local symbols.
-
#nlocrel ⇒ Integer
The number of local relocation entries.
-
#nmodtab ⇒ Integer
The number of entries in the module table.
-
#ntoc ⇒ Integer
The number of entries in the table of contents.
-
#nundefsym ⇒ Integer
The number of undefined symbols.
-
#to_h ⇒ Hash
A hash representation of this DysymtabCommand.
-
#tocoff ⇒ Integer
The file offset to the table of contents.
Methods inherited from LoadCommand
#cmd, #cmdsize, create, new_from_bin, #offset, #serializable?, #serialize, #to_s, #type, #view
Methods inherited from MachOStructure
bytesize, format, #initialize, new_from_bin
Constructor Details
This class inherits a constructor from MachO::MachOStructure
Instance Method Details
#extrefsymoff ⇒ Integer
Returns the file offset to the referenced symbol table.
912 |
# File 'lib/macho/load_commands.rb', line 912 field :extrefsymoff, :uint32 |
#extreloff ⇒ Integer
Returns the file offset to the external relocation entries.
924 |
# File 'lib/macho/load_commands.rb', line 924 field :extreloff, :uint32 |
#iextdefsym ⇒ Integer
Returns the index to externally defined symbols.
888 |
# File 'lib/macho/load_commands.rb', line 888 field :iextdefsym, :uint32 |
#ilocalsym ⇒ Integer
Returns the index to local symbols.
882 |
# File 'lib/macho/load_commands.rb', line 882 field :ilocalsym, :uint32 |
#indirectsymoff ⇒ Integer
Returns the file offset to the indirect symbol table.
918 |
# File 'lib/macho/load_commands.rb', line 918 field :indirectsymoff, :uint32 |
#iundefsym ⇒ Integer
Returns the index to undefined symbols.
894 |
# File 'lib/macho/load_commands.rb', line 894 field :iundefsym, :uint32 |
#locreloff ⇒ Integer
Returns the file offset to the local relocation entries.
930 |
# File 'lib/macho/load_commands.rb', line 930 field :locreloff, :uint32 |
#modtaboff ⇒ Integer
Returns the file offset to the module table.
906 |
# File 'lib/macho/load_commands.rb', line 906 field :modtaboff, :uint32 |
#nextdefsym ⇒ Integer
Returns the number of externally defined symbols.
891 |
# File 'lib/macho/load_commands.rb', line 891 field :nextdefsym, :uint32 |
#nextrefsyms ⇒ Integer
Returns the number of entries in the referenced symbol table.
915 |
# File 'lib/macho/load_commands.rb', line 915 field :nextrefsyms, :uint32 |
#nextrel ⇒ Integer
Returns the number of external relocation entries.
927 |
# File 'lib/macho/load_commands.rb', line 927 field :nextrel, :uint32 |
#nindirectsyms ⇒ Integer
Returns the number of entries in the indirect symbol table.
921 |
# File 'lib/macho/load_commands.rb', line 921 field :nindirectsyms, :uint32 |
#nlocalsym ⇒ Integer
Returns the number of local symbols.
885 |
# File 'lib/macho/load_commands.rb', line 885 field :nlocalsym, :uint32 |
#nlocrel ⇒ Integer
Returns the number of local relocation entries.
933 |
# File 'lib/macho/load_commands.rb', line 933 field :nlocrel, :uint32 |
#nmodtab ⇒ Integer
Returns the number of entries in the module table.
909 |
# File 'lib/macho/load_commands.rb', line 909 field :nmodtab, :uint32 |
#ntoc ⇒ Integer
Returns the number of entries in the table of contents.
903 |
# File 'lib/macho/load_commands.rb', line 903 field :ntoc, :uint32 |
#nundefsym ⇒ Integer
Returns the number of undefined symbols.
897 |
# File 'lib/macho/load_commands.rb', line 897 field :nundefsym, :uint32 |
#to_h ⇒ Hash
Returns a hash representation of this MachO::LoadCommands::DysymtabCommand.
936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 |
# File 'lib/macho/load_commands.rb', line 936 def to_h { "ilocalsym" => ilocalsym, "nlocalsym" => nlocalsym, "iextdefsym" => iextdefsym, "nextdefsym" => nextdefsym, "iundefsym" => iundefsym, "nundefsym" => nundefsym, "tocoff" => tocoff, "ntoc" => ntoc, "modtaboff" => modtaboff, "nmodtab" => nmodtab, "extrefsymoff" => extrefsymoff, "nextrefsyms" => nextrefsyms, "indirectsymoff" => indirectsymoff, "nindirectsyms" => nindirectsyms, "extreloff" => extreloff, "nextrel" => nextrel, "locreloff" => locreloff, "nlocrel" => nlocrel, }.merge super end |
#tocoff ⇒ Integer
Returns the file offset to the table of contents.
900 |
# File 'lib/macho/load_commands.rb', line 900 field :tocoff, :uint32 |