Class: MachO::LoadCommands::LoadCommand::SerializationContext

Inherits:
Object
  • Object
show all
Defined in:
lib/macho/load_commands.rb

Overview

Represents the contextual information needed by a load command to serialize itself correctly into a binary string.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(endianness, alignment) ⇒ SerializationContext

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of SerializationContext.

Parameters:

  • endianness (Symbol)

    the endianness of the context

  • alignment (Integer)

    the alignment of the context



392
393
394
395
# File 'lib/macho/load_commands.rb', line 392

def initialize(endianness, alignment)
  @endianness = endianness
  @alignment = alignment
end

Instance Attribute Details

#alignmentInteger (readonly)

Returns the constant alignment value used to pad the serialized load command.

Returns:

  • (Integer)

    the constant alignment value used to pad the serialized load command



380
381
382
# File 'lib/macho/load_commands.rb', line 380

def alignment
  @alignment
end

#endiannessSymbol (readonly)

Returns the endianness of the serialized load command.

Returns:

  • (Symbol)

    the endianness of the serialized load command



376
377
378
# File 'lib/macho/load_commands.rb', line 376

def endianness
  @endianness
end

Class Method Details

.context_for(macho) ⇒ SerializationContext

Returns the resulting context.

Parameters:

Returns:



385
386
387
# File 'lib/macho/load_commands.rb', line 385

def self.context_for(macho)
  new(macho.endianness, macho.alignment)
end