Class: MachO::LoadCommands::RoutinesCommand64

Inherits:
RoutinesCommand show all
Defined in:
lib/macho/load_commands.rb

Overview

A load command containing the address of the dynamic shared library initialization routine and an index into the module table for the module that defines the routine. Corresponds to LC_ROUTINES_64.

Instance Method Summary collapse

Methods inherited from RoutinesCommand

#to_h

Methods inherited from LoadCommand

#cmd, #cmdsize, create, new_from_bin, #offset, #serializable?, #serialize, #to_h, #to_s, #type, #view

Methods inherited from MachOStructure

bytesize, format, #initialize, new_from_bin, #to_h

Constructor Details

This class inherits a constructor from MachO::MachOStructure

Instance Method Details

#init_addressInteger

Returns the address of the initialization routine.

Returns:

  • (Integer)

    the address of the initialization routine



771
# File 'lib/macho/load_commands.rb', line 771

field :init_address, :uint64

#init_moduleInteger

Returns the index into the module table that the init routine is defined in.

Returns:

  • (Integer)

    the index into the module table that the init routine is defined in



775
# File 'lib/macho/load_commands.rb', line 775

field :init_module, :uint64

#reserved1void

This method returns an undefined value.



778
# File 'lib/macho/load_commands.rb', line 778

field :reserved1, :uint64

#reserved2void

This method returns an undefined value.



781
# File 'lib/macho/load_commands.rb', line 781

field :reserved2, :uint64

#reserved3void

This method returns an undefined value.



784
# File 'lib/macho/load_commands.rb', line 784

field :reserved3, :uint64

#reserved4void

This method returns an undefined value.



787
# File 'lib/macho/load_commands.rb', line 787

field :reserved4, :uint64

#reserved5void

This method returns an undefined value.



790
# File 'lib/macho/load_commands.rb', line 790

field :reserved5, :uint64

#reserved6void

This method returns an undefined value.



793
# File 'lib/macho/load_commands.rb', line 793

field :reserved6, :uint64