Method: MachO::LoadCommands::RpathCommand#path

Defined in:
lib/macho/load_commands.rb

#pathLCStr (readonly)

Returns the path to add to the run path as an LCStr.

Returns:

  • (LCStr)

    the path to add to the run path as an LCStr



1161
1162
1163
# File 'lib/macho/load_commands.rb', line 1161

def path
  @path
end